@@ -1,7 +1,5 @@
 package SQL::Translator::Parser;
 
-# ----------------------------------------------------------------------
-# $Id: Parser.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # ----------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -21,6 +19,8 @@ package SQL::Translator::Parser;
 # ----------------------------------------------------------------------
 
 use strict;
+use vars qw( $VERSION );
+$VERSION = '1.60';
 
 sub parse { "" }
 
@@ -60,7 +60,7 @@ source code for existing SQL::Translator::Parser::* modules.
 
 =head1 AUTHORS
 
-Ken Y. Clark, E<lt>kclark@cpan.org<gt>, 
+Ken Youens-Clark, E<lt>kclark@cpan.org<gt>, 
 darren chamberlain E<lt>darren@cpan.orgE<gt>.
 
 =head1 SEE ALSO
