@@ -5,8 +5,9 @@ create table person (
   weight double(11,2),
   iq int default '0',
   is_rock_star tinyint default '1',
-  description text,
-  UNIQUE KEY UC_person_id (person_id)
+  physical_description text,
+  UNIQUE KEY UC_person_id (person_id),
+  UNIQUE KEY UC_age_name (age, name)
 ) ENGINE=InnoDB;
 
 create unique index unique_name on person (name);
@@ -17,3 +18,8 @@ create table employee (
 	CONSTRAINT FK5302D47D93FE702E_diff FOREIGN KEY (employee_id) REFERENCES person (person_id),
 	PRIMARY KEY  (employee_id, position)
 ) ENGINE=InnoDB;
+
+create table added (
+  id integer
+);
+
